@@ -1,8 +1,8 @@
 # SPDX-FileCopyrightText: 2019-2022 Chris Zimmerman <chris@teffalump.com>
-# SPDX-FileCopyrightText: 2021-2023 Luis Falcón <falcon@gnuhealth.org>
+# SPDX-FileCopyrightText: 2021-2024 Luis Falcón <falcon@gnuhealth.org>
 # SPDX-FileCopyrightText: 2023 Patryk Rosik <p.rosik@stud.uni-hannover.de>
 # SPDX-FileCopyrightText: 2023 Feng Shu <tumashu@163.com>
-# SPDX-FileCopyrightText: 2021-2023 GNU Solidario <health@gnusolidario.org>
+# SPDX-FileCopyrightText: 2021-2024 GNU Solidario <health@gnusolidario.org>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #########################################################################
@@ -1158,8 +1158,12 @@ class ImagingTestRequest(metaclass=PoolMeta):
 
     def format_dicom_person_name(self, person_id):
         Pname = Pool().get('gnuhealth.person_name')
-        officialname = Pname.search(
-            [("party", "=", person_id), ("use", "=", 'official')])[0]
+
+        try:
+            officialname = Pname.search(
+                [("party", "=", person_id), ("use", "=", 'official')])[0]
+        except BaseException:
+            officialname = None
 
         if officialname:
             family = officialname.family or ''
@@ -1237,8 +1241,14 @@ class ImagingTestRequest(metaclass=PoolMeta):
         return name
 
     def getDicomInstitutionName(self):
-        institution = get_institution()
-        return institution and institution.rec_name or ''
+        # Return the name (string) of the institution
+        institution_id = get_institution()
+        if institution_id:
+            institution = \
+                Pool().get('gnuhealth.institution')(institution_id)
+            return institution.rec_name
+        else:
+            return ''
 
     def getDicomRequestedProcedureDescription(self):
         test = self.requested_test and self.requested_test.rec_name or ''
